@@ -5,7 +5,7 @@ import os.path
 import json
 import re
 
-__version__ = '1.0.3'
+__version__ = '1.0.6'
 
 def get_sexpr (pkg, code, i, canon=None):
     fraction_regex = re.compile("^[-+]?\\d+(/\\d+)?$")
@@ -440,7 +440,7 @@ class Acl2Kernel(Kernel):
             self.process_output("KeyboardInterrupt: Restarting ACL2")
             interrupted = True
         except ValueError as e:
-            self.process_output("ACL2 Syntax Error: " + e.message)
+            self.process_output("ACL2 Syntax Error: " + " ".join(e.args))
             self.status = 0
         except Exception as e:
             self.process_output("Unhandled Exception: " + str(e))
